@@ -17,6 +17,7 @@ from naas.types import t_main
 from datetime import datetime
 from sanic import Sanic
 import sentry_sdk
+import asyncio
 import getpass
 import uuid
 import os
@@ -49,6 +50,7 @@ class Runner():
     __testing = False
     tz = None
     user = None
+    __shell_user = None
     public_url = None
     proxy_url = None
             
@@ -56,8 +58,10 @@ class Runner():
         self.__path_user_files = os.environ.get('JUPYTER_SERVER_ROOT', '/home/ftp')
         self.__port = int(os.environ.get('NAAS_RUNNER_PORT', 5000))
         self.__user = os.environ.get('JUPYTERHUB_USER', 'joyvan@naas.com')
-        self.__public_url = os.environ.get('PUBLIC_DATASCIENCE', f'http://localhost:{self.__port}')
-        self.__proxy_url = os.environ.get('PUBLIC_PROXY_API', 'http://localhost:5002')
+        self.__shell_user = os.environ.get('USER', None)
+        self.__public_url = os.environ.get('JUPYTERHUB_URL', '')
+        self.__proxy_url = os.environ.get('PUBLIC_PROXY_API', 'http://localhost:3002')
+        self.__notifications_url = os.environ.get('NOTIFICATIONS_API', 'http://localhost:3003')
         self.__tz = os.environ.get('TZ', 'Europe/Paris')
         self.__path_naas_files = os.path.join(self.__path_user_files, self.__naas_folder)
         self.__path_html_files = os.path.join(self.__path_lib_files, self.__html_files)
@@ -104,8 +108,10 @@ class Runner():
         self.__notif = Notifications(self.__logger)
         self.__jobs = Jobs(self.__logger)
         self.__app = Sanic(__name__)
+        # TODO remove this fix when papermill support uvloop of Sanic support option to don't use uvloop 
+        asyncio.set_event_loop_policy(None)
         self.__app.register_listener(self.initialize_before_start, 'before_server_start')
-        self.__app.add_route(EnvController.as_view(self.__logger, self.__version, self.__user, self.__public_url, self.__proxy_url, self.__tz), '/env')
+        self.__app.add_route(EnvController.as_view(self.__logger, self.__user, self.__public_url, self.__proxy_url, self.__notifications_url, self.__tz), '/env')
         self.__app.add_route(LogsController.as_view(self.__logger), '/logs')
         self.__app.add_route(JobsController.as_view(self.__logger, self.__jobs), '/jobs')
         self.__app.add_route(StaticController.as_view(self.__logger,  self.__jobs, self.__path_lib_files), '/static/<token>')
@@ -118,8 +124,8 @@ class Runner():
                 
     def start(self, deamon=True, port=None, debug=True):
         user = getpass.getuser()
-        if (user != self.__user):
-            raise Exception(f"{user} not autorized, use {self.__user} instead")
+        if (user != self.__shell_user):
+            raise Exception(f"{user} not autorized, use {self.__shell_user} instead")
         self.kill()
         if port:
             self.__port = port
